from BrickBreaker.Bricks.brick import *
from BrickBreaker.Bricks.life_brick import *
from BrickBreaker.Bricks.speed_brick import *
from BrickBreaker.Bricks.size_brick import *
from BrickBreaker.Bricks.ball_brick import *
